@@ -2,7 +2,7 @@
 
 # maybe this module should be broken up into multiple files, or maybe not ...
 
-UA = "diffengine/0.0.31 (+https://github.com/docnow/diffengine)"
+UA = "diffengine/0.0.33 (+https://github.com/docnow/diffengine)"
 
 import os
 import re
@@ -236,8 +236,8 @@ class EntryVersion(BaseModel):
                 self.save()
                 return self.archive_url
             else:
-                logging.error("unable to get archive id for %s: %s", url, 
-                    resp.headers)
+                logging.error("unable to get archive id from %s: %s",
+                        self.archive_url, resp.headers)
 
         except Exception as e:
             logging.error("unexpected archive.org response for %s: %s", save_url, e)
@@ -444,6 +444,7 @@ def main():
     checked = skipped = new = 0
 
     for f in config.get('feeds', []):
+        print(dir(Feed))
         feed, created = Feed.create_or_get(url=f['url'], name=f['name'])
         if created:
             logging.debug("created new feed for %s", f['url'])
